#[non_exhaustive]pub struct WorkspaceOptions {
pub max_bytes: u64,
pub max_nodes: u64,
pub max_file_bytes: u64,
}Expand description
Configurable per-workspace resource limits.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.max_bytes: u64The maximum total logical bytes the workspace may hold.
max_nodes: u64The maximum number of active nodes the workspace may hold.
max_file_bytes: u64The maximum logical size of a single regular file.